package com.zswl.cloud.springBtach.server.core.service;


import cn.hutool.json.JSONUtil;
import com.github.microservice.auth.client.content.ResultContent;
import com.github.microservice.auth.security.helper.AuthHelper;
import com.xiaoju.open.oil.commons.OilRequest;
import com.xiaoju.open.oil.commons.config.OilConfig;
import com.xiaoju.open.oil.core.QueryClient;
import com.xiaoju.open.oil.core.QueryClientFactory;
import com.xiaoju.open.oil.core.executor.ResponseDTO;
import com.xiaoju.open.oil.interfaces.domain.AllowanceInfo;
import com.xiaoju.open.oil.interfaces.request.*;
import com.xiaoju.open.oil.interfaces.response.*;
import com.xiaoju.open.oil.security.secret.SecurityService;
import com.zswl.cloud.springBatch.client.model.request.NearbyModel;
import com.zswl.cloud.springBatch.client.model.request.QueryCalPriceModel;
import com.zswl.cloud.springBatch.client.model.request.QueryCalPricesModel;
import com.zswl.cloud.springBtach.server.core.dao.XiaoJuStoreDao;
import com.zswl.cloud.springBtach.server.core.domain.XiaoJuStore;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Log4j2
@Service
public class XiaoJuService {


    @Autowired
    AuthHelper authHelper;

    @Autowired
    XiaoJuStoreDao xiaoJuStoreDao;

    @Autowired
    OilConfig oilConfig;

    // 查询加油站详情
    public ResponseDTO notificationPushStoreInfoRequest(OilRequest oilRequest) {

        log.info("加油站通知原始数据：{}", oilRequest);

        String s = SecurityService.genDecodeData(oilRequest.getData(), oilConfig.getDataSecret(), oilConfig.getDataSecretIV());

        log.info("通知 加油站详情：{}", s);
        XiaoJuStore xiaoJuStore = JSONUtil.toBean(s, XiaoJuStore.class);

        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(xiaoJuStore.getStoreId());
        if (byStoreId != null) {
            BeanUtils.copyProperties(byStoreId, xiaoJuStore, "id", "updateTime");
            byStoreId.setLocation(new double[]{xiaoJuStore.getLon(), xiaoJuStore.getLat()});
            xiaoJuStoreDao.save(byStoreId);
        } else {
            xiaoJuStore.setLocation(new double[]{xiaoJuStore.getLon(), xiaoJuStore.getLat()});
            xiaoJuStoreDao.save(xiaoJuStore);
        }


        String data = SecurityService.genEncodeData("{\"success\":true,\"msg\":\"ok\"}", oilConfig.getDataSecret(), oilConfig.getDataSecretIV());
        String sig = SecurityService.genSigData(data, oilConfig.getDataSecret());
        ResponseDTO responseDTO = new ResponseDTO();
        responseDTO.setAppKey(oilConfig.getAppId());
        responseDTO.setCode("0");
        responseDTO.setMsg("请求成功");
        responseDTO.setData(data);
        responseDTO.setSig(sig);
        return responseDTO;

    }

    public ResponseDTO notifyOrderInfo(OilRequest oilRequest) {


        String s = SecurityService.genDecodeData(oilRequest.getData(), oilConfig.getDataSecret(), oilConfig.getDataSecretIV());

        log.info("通知 加油站详情：{}", s);
        NotificationReceiveRefundRequest xiaoJuStore = JSONUtil.toBean(s, NotificationReceiveRefundRequest.class);


        String data = SecurityService.genEncodeData("{\"success\":true,\"msg\":\"ok\"}", oilConfig.getDataSecret(), oilConfig.getDataSecretIV());
        String sig = SecurityService.genSigData(data, oilConfig.getDataSecret());
        ResponseDTO responseDTO = new ResponseDTO();
        responseDTO.setAppKey(oilConfig.getAppId());
        responseDTO.setCode("0");
        responseDTO.setMsg("请求成功");
        responseDTO.setData(data);
        responseDTO.setSig(sig);
        return responseDTO;

    }

    public ResultContent<QueryStoreDetailResponse> queryStoreDetail(String storeId) {
        XiaoJuStore byStoreId = xiaoJuStoreDao.findByStoreId(storeId);
        QueryStoreDetailRequest queryStoreDetailRequest = new QueryStoreDetailRequest();

        queryStoreDetailRequest.setOutUserId(authHelper.getCurrentUser().getUserId());
        queryStoreDetailRequest.setStoreId(storeId);
        queryStoreDetailRequest.setLat(byStoreId.getLat());
        queryStoreDetailRequest.setLon(byStoreId.getLon());
        queryStoreDetailRequest.setOpenChannel(1);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryStoreDetailResponse queryStoreDetailResponse = queryClient.api().queryStoreDetail(queryStoreDetailRequest);

        return ResultContent.buildContent(queryStoreDetailResponse);
    }

    public ResultContent<List<QueryApiStorePriceResponse>> queryStorePrice(List<String> storeIdList) {
        String userId = authHelper.getCurrentUser().getUserId();
        QueryApiStorePriceRequest queryApiStorePriceRequest = new QueryApiStorePriceRequest();
        queryApiStorePriceRequest.setOpenChannel(1);
        queryApiStorePriceRequest.setOutUserId(userId);
        queryApiStorePriceRequest.setStoreIds(storeIdList);


        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        List<QueryApiStorePriceResponse> list1 = queryClient.api().queryStorePrice(queryApiStorePriceRequest);
        return ResultContent.buildContent(list1);
    }


    public ResultContent<List<XiaoJuStore>> nearbyStore(NearbyModel nearbyModel) {

        List<XiaoJuStore> nearbyTargets = xiaoJuStoreDao.findNearbyTargets(nearbyModel);
        return ResultContent.buildContent(nearbyTargets);
    }


    // 价格计算
    public ResultContent<QueryCalPriceResponse> queryCalPrice(QueryCalPriceModel queryCalPriceModel) {

        String userId = authHelper.getCurrentUser().getUserId();
        QueryCalPriceRequest queryCalPriceRequest = new QueryCalPriceRequest();
        queryCalPriceRequest.setStoreId(queryCalPriceModel.getStoreId());
        queryCalPriceRequest.setOpenChannel(1);
        queryCalPriceRequest.setOutUserId(userId);
        queryCalPriceRequest.setItemName(queryCalPriceModel.getItemName());
        queryCalPriceRequest.setAmount(queryCalPriceModel.getAmount());

        queryCalPriceRequest.setPromotionInfo(queryCalPriceModel.getAllowanceinfo());

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryCalPriceResponse queryCalPriceResponse = queryClient.api().queryCalPrice(queryCalPriceRequest);


        return ResultContent.buildContent(queryCalPriceResponse);
    }


    // 批量价格计算
    public ResultContent<QueryCalBatchPriceResponse> queryCalPrices(QueryCalPricesModel queryCalPricesModel) {

        String userId = authHelper.getCurrentUser().getUserId();
        QueryCalBatchPriceRequest queryCalPriceRequest = new QueryCalBatchPriceRequest();
        queryCalPriceRequest.setStoreId(queryCalPricesModel.getStoreId());
        queryCalPriceRequest.setOpenChannel(1);
        queryCalPriceRequest.setOutUserId(userId);

        queryCalPriceRequest.setItemList(queryCalPricesModel.getItemList());

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryCalBatchPriceResponse queryCalBatchPriceResponse = queryClient.api().queryCalPrices(queryCalPriceRequest);

        return ResultContent.buildContent(queryCalBatchPriceResponse);

    }


    // 创建订单
    public void queryNewOrder() {
        QueryNewOrderRequest queryNewOrderRequest = new QueryNewOrderRequest();
        queryNewOrderRequest.setOutUserId("a09kWkRLM2ZWcWs9");
        queryNewOrderRequest.setMobile("13111222233");
        queryNewOrderRequest.setOutOrderId("123456789");
        queryNewOrderRequest.setLat(114.30F);
        queryNewOrderRequest.setLon(14.23F);
        queryNewOrderRequest.setStoreId("5211967762877389105");
        queryNewOrderRequest.setItemId(4879454965524071453L);
        queryNewOrderRequest.setGunNo("10");
        queryNewOrderRequest.setOriginalAmount(20000);
        queryNewOrderRequest.setPaymentAmount(18000);
        queryNewOrderRequest.setServiceFee(20);
        queryNewOrderRequest.setLitre(382);
        queryNewOrderRequest.setVipPrice(460);
        queryNewOrderRequest.setStorePrice(523);

        // 优惠券
        List<AllowanceInfo> allowanceInfos = new ArrayList<>();
        AllowanceInfo allowanceInfo = new AllowanceInfo();
        allowanceInfo.setAllowanceId("E1-4ji-1kiJSL");
        allowanceInfo.setAllowanceType(2);
        allowanceInfos.add(allowanceInfo);

        queryNewOrderRequest.setPromotionInfo(allowanceInfos);

        QueryClient queryClient = QueryClientFactory.create(oilConfig);

        QueryNewOrderResponse queryNewOrderResponse = queryClient.api().queryNewOrder(queryNewOrderRequest);


    }

}
